@@ -575,13 +575,17 @@ class BaseExperiment:
         
         self.fit_or_cv = fit_or_cv
         self.update_log_path()
-        if self.data_module is None:
-            self.data_module = self.get_data_module()
+        if self.data_module:
+            del self.data_module
+        self.data_module = None
+        
+        self.data_module = self.get_data_module()
         if self.logger:
             self.logger.close()
             del self.logger
             self.logger = None
         if BaseEstimator in inspect.getmro(self.model.__class__):
+            self.X_train, self.X_val, self.y_train, self.y_val, self.X_test, self.y_test = self.data_module
             return self.fit_sklearn(sample_weight=sample_weight, **config)
         elif pl.LightningModule in inspect.getmro(self.model.__class__):
             return self.fit_lightning(**config)
