@@ -71,7 +71,7 @@ class _MLP(nn.Module):
         super(_MLP, self).__init__()
         layers = []
         
-        if isinstance(dims, tuple):
+        if not isinstance(dims, int):
             flattened = 1
             for dim in dims:
                 flattened *= dim
@@ -229,9 +229,6 @@ class MLP(BaseNet):
             'n_hidden_units' : 10
         }
         
-        self.dims = dims
-        self.n_classes = n_classes
-        self.sample_weight = sample_weight
         
         # set default for model-specific hyperparameters
         for argument, default in default_parameter_dict.items():
@@ -319,7 +316,7 @@ class _ContractingMLP(nn.Module):
     """
         super(_ContractingMLP, self).__init__()
 
-        if isinstance(dims, tuple):
+        if not isinstance(dims, int):
             flattened = 1
             for dim in dims:
                 flattened *= dim
@@ -617,7 +614,7 @@ class _CustomMLP(nn.Module):
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None
     ) -> None:
         super(_CustomMLP, self).__init__()
-        if isinstance(dims, tuple):
+        if not isinstance(dims, int):
             flattened = 1
             for dim in dims:
                 flattened *= dim
